.. highlight:: shell

============
Installation
============


Stable release
--------------

To install Number Recognizer, first install OpenCV_ and TensorFlow_ then run this command in your terminal:

.. code-block:: console

    $ pip install number-recognizer

This is the preferred method to install Number Recognizer, as it will always install the most recent stable release. 

If you don't have `pip`_ installed, this `Python installation guide`_ can guide
you through the process.

.. _pip: https://pip.pypa.io
.. _Python installation guide: http://docs.python-guide.org/en/latest/starting/installation/


From sources
------------

The sources for Number Recognizer can be downloaded from the `Github repo`_.

First install OpenCV_ and TensorFlow_.

You can either clone the public repository:

.. code-block:: console

    $ git clone git://github.com/condereis/number-recognizer

Or download the `tarball`_:

.. code-block:: console

    $ curl  -OL https://github.com/condereis/number-recognizer/tarball/master

Once you have a copy of the source, you can install it with:

.. code-block:: console

    $ python setup.py install


.. _Github repo: https://github.com/condereis/number-recognizer
.. _tarball: https://github.com/condereis/number-recognizer/tarball/master
.. _OpenCV: https://github.com/milq/scripts-ubuntu-debian/blob/master/install-opencv.sh
.. _TensorFlow: https://www.tensorflow.org/versions/r0.10/get_started/os_setup.html#pip-installation
